@@ -1,9 +1,12 @@
-from typing import Any
+from typing import Any, Callable, Coroutine, TypeVar, Union
 
 
-def getattr_safe(o: object, name: str, default: Any = "_UNKNOWN_") -> Any:
-    """
-    Wrap `getattr` with try/except to never raise exception
+V = TypeVar('V')
+D = TypeVar('D')
+
+
+def getattr_safe(o: object, name: str, default: Any = '_UNKNOWN_') -> Any:
+    """Wrap `getattr` with try/except to never raise exception.
 
     Usage
 
@@ -23,9 +26,8 @@ def getattr_safe(o: object, name: str, default: Any = "_UNKNOWN_") -> Any:
         return default
 
 
-def getattrs_safe(o: object, *names: str, default: Any = "_UNKNOWN_") -> list:
-    """
-    Run `getattr_safe` on each attribute name and return results
+def getattrs_safe(o: object, *names: str, default: Any = '_UNKNOWN_') -> list:
+    """Run `getattr_safe` on each attribute name and return results.
 
     Usage
 
@@ -41,3 +43,19 @@ def getattrs_safe(o: object, *names: str, default: Any = "_UNKNOWN_") -> list:
       [1, 'my_default']
     """
     return [getattr_safe(o, n, default) for n in names]
+
+
+def run_safe(func: Callable[[], V], default: D) -> Union[V, D]:
+    """Run function and return result. return `default` if failed."""
+    try:
+        return func()
+    except Exception:
+        return default
+
+
+async def run_async_safe(func: Callable[[], Coroutine[Any, Any, V]], default: D) -> Union[V, D]:
+    """Run async function and return result. return `default` if failed."""
+    try:
+        return await func()
+    except Exception:
+        return default
